@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Main Wammu application
@@ -6,7 +7,7 @@ Main Wammu application
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -26,13 +27,17 @@ import wx
 import sys
 import Wammu.Main
 import Wammu.Error
-from Wammu.Paths import *
-from Wammu.Utils import Str_ as _, StrConv
+from Wammu.Locales import StrConv
 
 class WammuApp(wx.App):
+    '''
+    Wammu appliction class, it initializes wx and creates main Wammu window.
+    '''
 
-    # wxWindows calls this method to initialize the application
     def OnInit(self):
+        '''
+        wxWindows call this method to initialize the application.
+        '''
 
         self.SetAppName('Wammu')
         vendor = StrConv(u'Michal Čihař')
@@ -43,7 +48,7 @@ class WammuApp(wx.App):
         wx.InitAllImageHandlers()
 
         frame = Wammu.Main.WammuFrame(None, -1)
-        Wammu.Error.handlerparent = frame
+        Wammu.Error.HANDLER_PARENT = frame
 
         frame.Show(True)
         frame.PostInit()
@@ -53,6 +58,10 @@ class WammuApp(wx.App):
         return True
 
 def Run():
+    '''
+    Wrapper to execute Wammu. Installs graphical error handler and launches
+    WammuApp.
+    '''
     try:
         sys.excepthook = Wammu.Error.Handler
     except:
