@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Item editors
@@ -6,7 +7,7 @@ Item editors
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -23,23 +24,10 @@ this program; if not, write to the Free Software Foundation, Inc.,
 '''
 
 import wx
-try:
-    # wxPython 2.4
-    from wxPython.utils import wxDateTimeFromDMY as DateTimeFromDMY, wxDateTime_Today as DateTime_Today
-except ImportError:
-    try:
-        # wxPython 2.5.1
-        from wx.misc import DateTimeFromDMY, DateTime_Today
-    except ImportError:
-        # wxPython 2.5.2
-        from wx import DateTimeFromDMY, DateTime_Today
-
+from wx import DateTimeFromDMY, DateTime_Today
 import wx.calendar
-try:
-    from wx.lib.timectrl import TimeCtrl
-except ImportError:
-    # wxPython 2.5.2
-    from wx.lib.masked.timectrl import TimeCtrl
+import wx.lib.masked.timectrl
+from wx.lib.masked import Ctrl as maskedCtrl
 from Wammu.Paths import *
 import sys
 import datetime
@@ -49,21 +37,23 @@ import Wammu.Data
 import Wammu.Utils
 import Wammu.Select
 import Wammu.PhoneValidator
-from Wammu.Utils import StrConv, UnicodeConv, Str_ as _
-try:
-    from wx.lib.masked import Ctrl as maskedCtrl
-except ImportError:
-    # wxPython 2.5
-    from wx.lib.maskedctrl import MaskedCtrl as maskedCtrl
+from Wammu.Locales import StrConv, UnicodeConv
 
 
-def TextToTime(txt):
+def TextToTime(txt, config):
     hms = txt.split(':')
-    return datetime.time(int(hms[0]), int(hms[1]), int(hms[2]))
+    try:
+        return datetime.time(int(hms[0]), int(hms[1]), int(hms[2]))
+    except UnicodeEncodeError:
+        hms = config.Read('/Wammu/DefaultTime').split(':')
+        return datetime.time(int(hms[0]), int(hms[1]), int(hms[2]))
 
 def TextToDate(txt):
     dmy = txt.split('.')
-    return datetime.date(int(dmy[2]), int(dmy[1]), int(dmy[0]))
+    try:
+        return datetime.date(int(dmy[2]), int(dmy[1]), int(dmy[0]))
+    except UnicodeEncodeError:
+        return datetime.date.today()
 
 def TimeToText(time, config):
     try:
@@ -73,7 +63,7 @@ def TimeToText(time, config):
             pass
         return time.isoformat()
     except:
-        return config.Read('Wammu/DefaultTime', '9:00:00')
+        return config.Read('/Wammu/DefaultTime')
 
 def DateToText(date, config):
     try:
@@ -83,7 +73,11 @@ def DateToText(date, config):
             pass
         return date.strftime('%d.%m.%Y')
     except:
-        return datetime.datetime.fromtimestamp(time.time() + 24*60*60*config.ReadInt('/Wammu/DefaultDateOffset', 1)).date().strftime('%d.%m.%Y')
+        return datetime.datetime.fromtimestamp(time.time() + 24*60*60*config.ReadInt('/Wammu/DefaultDateOffset')).date().strftime('%d.%m.%Y')
+
+class TimeCtrl(wx.lib.masked.timectrl.TimeCtrl):
+    def Validate(self):
+        return self.IsValid(self.GetValue())
 
 class CalendarPopup(wx.PopupTransientWindow):
     def __init__(self, parent):
@@ -190,7 +184,7 @@ class ContactEdit(wx.Panel):
         self.sizer.AddGrowableCol(1)
         self.edit = wx.SpinCtrl(self, -1, str(val), style = wx.SP_WRAP|wx.SP_ARROW_KEYS, min = 0, max = 10000, initial = val, size = (200, -1))
         self.txt = wx.StaticText(self, -1, self.GetText(val))
-        self.btn = wx.Button(self, -1, _('...'), style = wx.BU_EXACTFIT)
+        self.btn = wx.Button(self, -1, '...', style = wx.BU_EXACTFIT)
         self.sizer.AddMany([
             (self.edit,                     0, wx.EXPAND),
             (self.txt,                      1, wx.EXPAND),
@@ -274,16 +268,20 @@ class GenericEditor(wx.Dialog):
         self.fulltypes = {}
         x = 0
         if wasempty:
-            for x in range(self.cfg.ReadInt('/Wammu/DefaultEntries', 3)):
+            for x in range(self.cfg.ReadInt('/Wammu/DefaultEntries')):
                 self.AddEdit(x)
         else:
             for i in range(len(entry['Entries'])):
                 self.AddEdit(i, entry['Entries'][i])
 
-        self.ok = wx.Button(self, wx.ID_OK, _('OK'))
-        self.Bind(wx.EVT_BUTTON, self.Okay, self.ok)
-        self.cancel = wx.Button(self, wx.ID_CANCEL, _('Cancel'))
-        self.more = wx.Button(self, -1, _('More'))
+        self.more = wx.Button(self, wx.ID_ADD)
+        self.more.SetToolTipString(_('Add one more field.'))
+        self.button_sizer = wx.StdDialogButtonSizer()
+        self.button_sizer.AddButton(wx.Button(self, wx.ID_OK))
+        self.button_sizer.AddButton(wx.Button(self, wx.ID_CANCEL))
+        self.button_sizer.SetNegativeButton(self.more)
+        self.button_sizer.Realize()
+        self.Bind(wx.EVT_BUTTON, self.Okay, id = wx.ID_OK)
         self.Bind(wx.EVT_BUTTON, self.More, self.more)
 
         self.SetAutoLayout(True)
@@ -292,17 +290,14 @@ class GenericEditor(wx.Dialog):
         self.AddButtons()
 
     def AddButtons(self):
-        self.sizer.Add(self.ok, (self.rowoffset + self.rows + 1, 0), (1, 2))
-        self.sizer.Add(self.more, (self.rowoffset + self.rows + 1, 3), (1, 2))
-        self.sizer.Add(self.cancel, (self.rowoffset + self.rows + 1, 6), (1, 2))
+        row = self.rowoffset + self.rows + 1
+        self.sizer.Add(self.button_sizer, pos = (row, 1), span = wx.GBSpan(colspan = 7), flag = wx.ALIGN_RIGHT)
         self.sizer.Fit(self)
         self.sizer.SetSizeHints(self)
         self.sizer.Layout()
 
     def RemoveButtons(self):
-        self.sizer.Detach(self.ok)
-        self.sizer.Detach(self.more)
-        self.sizer.Detach(self.cancel)
+        self.sizer.Detach(self.button_sizer)
 
     def AddEdit(self, row, value = {'Type':'', 'Value':''}):
         self.rows += 1
@@ -436,7 +431,7 @@ class GenericEditor(wx.Dialog):
         if self.types[row] == 'date':
             return TextToDate(self.edits[row][0].GetValue())
         elif self.types[row] == 'datetime':
-            return datetime.datetime.combine(TextToDate(self.edits[row][1].GetValue()), TextToTime(self.edits[row][0].GetValue()))
+            return datetime.datetime.combine(TextToDate(self.edits[row][1].GetValue()), TextToTime(self.edits[row][0].GetValue(), self.cfg))
         elif self.types[row] == 'id':
             return int(self.edits[row][0].GetValue(), 16)
         elif self.types[row] in ['contact', 'bool', 'category', 'number']:
@@ -468,10 +463,10 @@ class GenericEditor(wx.Dialog):
 
     def Okay(self, evt):
         # FIXME: why it needed to call validators directly?
-#        for e in self.edits:
-#            for i in e:
-#                if i.hasattr('Validate') and not i.Validate():
-#                    return
+        for row in self.edits.keys():
+            for input in self.edits[row]:
+                if hasattr(input, 'Validate') and not input.Validate():
+                    return
 
         v = []
         for row in range(self.rows):
@@ -507,3 +502,7 @@ class TodoEditor(GenericEditor):
         else:
             location = '%d' % entry['Location']
         GenericEditor.__init__(self, parent, cfg, values, entry, 'todo',  _('todo item'), location, 'Priority', 'Medium', _('Priority'), Wammu.Data.TodoPriorities, Wammu.Data.TodoValueTypes)
+
+    def Okay(self, evt):
+        self.entry['Type'] = 'MEMO'
+        GenericEditor.Okay(self, evt)
