@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Searching for phone
@@ -6,7 +7,7 @@ Searching for phone
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -24,15 +25,20 @@ this program; if not, write to the Free Software Foundation, Inc.,
 
 import wx
 import threading
+import os
 import os.path
 import sys
+try:
+    import grp
+except ImportError:
+    pass
 import Wammu
 if Wammu.gammu_error == None:
     import gammu
 import Wammu.Data
 import Wammu.Events
-import wxPython.lib.layoutf
-from Wammu.Utils import StrConv, Str_ as _
+import wx.lib.layoutf
+from Wammu.Locales import StrConv
 
 class LogDialog(wx.Dialog):
     def __init__(self, parent, msg = '', caption = _('Phone searching log'), pos = wx.DefaultPosition, size = (500,300)):
@@ -44,8 +50,8 @@ class LogDialog(wx.Dialog):
                              wx.DefaultSize,
                              wx.TE_MULTILINE | wx.TE_READONLY)
         ok = wx.Button(self, wx.ID_OK, _('Close'))
-        text.SetConstraints(wxPython.lib.layoutf.Layoutf('t=t5#1;b=t5#2;l=l5#1;r=r5#1', (self,ok)))
-        ok.SetConstraints(wxPython.lib.layoutf.Layoutf('b=b5#1;x%w50#1;w!80;h!25', (self,)))
+        text.SetConstraints(wx.lib.layoutf.Layoutf('t=t5#1;b=t5#2;l=l5#1;r=r5#1', (self,ok)))
+        ok.SetConstraints(wx.lib.layoutf.Layoutf('b=b5#1;x%w50#1;w!80;h!25', (self,)))
         self.SetAutoLayout(1)
         self.Layout()
         self.text = text
@@ -69,7 +75,7 @@ class LogDialog(wx.Dialog):
 
 
 class AllSearchThread(threading.Thread):
-    def __init__(self, lock = 'no', level = 'nothing', msgcallback = None, callback = None, win = None):
+    def __init__(self, lock = 'no', level = 'nothing', msgcallback = None, callback = None, win = None, noticecallback = None):
         threading.Thread.__init__(self)
         self.lock = lock
         self.list = []
@@ -79,6 +85,7 @@ class AllSearchThread(threading.Thread):
         self.threads = []
         self.callback = callback
         self.msgcallback = msgcallback
+        self.noticecallback = noticecallback
 
     def run(self):
         try:
@@ -86,8 +93,23 @@ class AllSearchThread(threading.Thread):
                 if dev[1].find('%d') >= 0:
                     for i in range(*dev[2]):
                         curdev = dev[1] % i
-                        if curdev[0] == '/' and not os.path.exists(curdev):
-                            continue
+                        if curdev[0] == '/':
+                            if not os.path.exists(curdev):
+                                continue
+                            if not os.access(curdev, os.R_OK) or not os.access(curdev, os.W_OK):
+                                gid =  os.stat(curdev).st_gid
+                                try:
+                                    group = grp.getgrgid(gid)[0]
+                                except NameError:
+                                    group = str(gid)
+                                if self.msgcallback != None:
+                                    self.msgcallback(_('You don\'t have permissions for %s device!') % curdev)
+                                if self.noticecallback != None:
+                                    self.noticecallback(
+                                            _('Error opening device'), 
+                                            (_('You don\'t have permissions for %s device!') % curdev) + ' ' +
+                                            (_('Maybe you need to be member of %s group.') % group))
+
                         t = SearchThread(curdev, dev[0], self.list, self.listlock, self.lock, self.level, self.win)
                         t.setName('%s - %s' % (curdev, str(dev[0])))
                         if self.msgcallback != None:
@@ -138,7 +160,7 @@ class AllSearchThread(threading.Thread):
                         ctl = btctl.Controller()
                     # read devices list
                     if self.msgcallback != None:
-                        self.msgcallback(_('Scanning for bluetooth devices using %s') % 'GNOME Bluetooth')
+                        self.msgcallback(_('Scanning for bluetooth devices using %s') % 'GNOME Bluetooth (btctl)')
 
                     devs = ctl.discover_devices()
 
@@ -157,7 +179,11 @@ class AllSearchThread(threading.Thread):
                         self.msgcallback(_('Bluetooth device scan completed'))
                 except ImportError:
                     if self.msgcallback != None:
-                        self.msgcallback(_('Neither GNOME Bluetooth nor PyBluez found, not possible to scan for bluetooth devices'))
+                        self.msgcallback(_('Neither GNOME Bluetooth (btctl) nor PyBluez found, not possible to scan for bluetooth devices'))
+                    if self.noticecallback != None:
+                        self.noticecallback(
+                                _('No bluetooth searching'), 
+                                _('Neither GNOME Bluetooth (btctl) nor PyBluez found, not possible to scan for bluetooth devices'))
 
             i = 0
             while len(self.threads) > 0:
@@ -220,3 +246,33 @@ class SearchThread(threading.Thread):
         except:
             evt = Wammu.Events.ExceptionEvent(data = sys.exc_info())
             wx.PostEvent(self.win, evt)
+
+class PhoneInfoThread(threading.Thread):
+    def __init__(self, win, device, connection):
+        threading.Thread.__init__(self)
+        self.device = device
+        self.connection = connection
+        self.result = None
+        self.win = win
+
+    def run(self):
+        try:
+            sm = gammu.StateMachine()
+            sm.SetConfig(0,
+                    {'StartInfo': 'no',
+                     'UseGlobalDebugFile': 1,
+                     'DebugFile': '',
+                     'SyncTime': 'no',
+                     'Connection': self.connection,
+                     'LockDevice': 'no',
+                     'DebugLevel': 'nothing',
+                     'Device': self.device,
+                     'Localize': None,
+                     'Model': ''})
+            sm.Init()
+            self.result = {'Model': sm.GetModel(), 'Manufacturer': sm.GetManufacturer()}
+            evt = Wammu.Events.DataEvent(data = self.result)
+            wx.PostEvent(self.win, evt)
+        except gammu.GSMError:
+            evt = Wammu.Events.DataEvent(data = None)
+            wx.PostEvent(self.win, evt)
