@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Contact and phone number select dialogs
@@ -6,7 +7,7 @@ Contact and phone number select dialogs
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -24,7 +25,7 @@ this program; if not, write to the Free Software Foundation, Inc.,
 
 import wx
 import Wammu.Utils
-from Wammu.Utils import StrConv, Str_ as _
+from Wammu.Locales import StrConv
 
 def SortName(i1, i2):
     return cmp(i1['Name'], i2['Name'])
@@ -33,7 +34,10 @@ def SelectContact(parent, list, index = False):
     list.sort(SortName)
     choices = []
     for e in list:
-        choices.append(StrConv(e['Name']))
+        if e['Name'] == '':
+            choices.append(StrConv(e['Number']))
+        else:
+            choices.append(StrConv(e['Name']))
 
     dlg = wx.SingleChoiceDialog(parent, _('Select contact from bellow list'), _('Select contact'),
                                 choices, wx.CHOICEDLG_STYLE | wx.RESIZE_BORDER)
