@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Generic thread wrapper used for reading things from phone
@@ -6,7 +7,7 @@ Generic thread wrapper used for reading things from phone
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -26,7 +27,6 @@ import sys
 import threading
 import wx
 import Wammu.Events
-from Wammu.Utils import Str_ as _
 
 class Thread(threading.Thread):
     def __init__(self, win, sm):
@@ -55,6 +55,7 @@ class Thread(threading.Thread):
             message = Wammu.Utils.FormatError(_('Error while communicating with phone'), info),
             title = _('Error Occured'),
             type = wx.ICON_ERROR,
+            errortype = 'gammu',
             lock = lck)
         wx.PostEvent(self.win, evt)
         lck.acquire()
