@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Misc functions like charset conversion, entries parsers,..
@@ -6,7 +7,7 @@ Misc functions like charset conversion, entries parsers,..
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -22,135 +23,28 @@ this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 '''
 
-import wx
 import codecs
 import locale
 import sys
 import re
+import wx
 import string
+import Wammu.Locales
+from Wammu.Locales import StrConv
 
 import Wammu
 if Wammu.gammu_error == None:
     import gammu
 
-fallbacklocalecharset = 'iso-8859-1'
-
-# Determine "correct" character set
-try:
-    # works only in python > 2.3
-    localecharset = locale.getpreferredencoding()
-except:
-    try:
-        localecharset = locale.getdefaultlocale()[1]
-    except:
-        try:
-            localecharset = sys.getdefaultencoding()
-        except:
-            localecharset = fallbacklocalecharset
-if localecharset in [None, 'ANSI_X3.4-1968']:
-    localecharset = fallbacklocalecharset
-
-# prepare encoder for strings
-charsetencoder = codecs.getencoder(localecharset)
-
-def StrConv(txt):
-    """
-    This function coverts something (txt) to string form usable by wxPython. There
-    is problem that in default configuration in most distros (maybe all) default
-    encoding for unicode objects is ascii. This leads to exception when converting
-    something different than ascii. And this exception is not catched inside
-    wxPython and leads to segfault.
-
-    So if wxPython supports unicode, we give it unicode, otherwise locale
-    dependant text.
-    """
-    try:
-        if wx.USE_UNICODE:
-            if type(txt) == type(u''):
-                return txt
-            if type(txt) == type(''):
-                return unicode(txt, localecharset)
-        else:
-            if type(txt) == type(''):
-                return txt
-            if type(txt) == type(u''):
-                return str(charsetencoder(txt, 'replace')[0])
-        return str(txt)
-    except UnicodeEncodeError:
-        return '???'
-
-# detect html charset
-htmlcharset = localecharset
-if localecharset.lower() == 'utf-8' and not wx.USE_UNICODE:
-    htmlcharset = 'iso-8859-1'
-    if locale.getdefaultlocale()[0][:2] in ['cs', 'pl', 'sk']:
-        htmlcharset = 'iso-8859-2'
-    print StrConv(_('Warning: you are using utf-8 locales and non unicode enabled wxPython, some text migth be displayed incorrectly!'))
-    print StrConv(_('Warning: assuming charset %s for html widget') % htmlcharset)
-
-# prepare html encoder
-htmlencoder = codecs.getencoder(htmlcharset)
-
-def HtmlStrConv(txt):
-    """
-    This function coverts something (txt) to string form usable by wxPython
-    html widget. There is problem that in default configuration in most distros
-    (maybe all) default encoding for unicode objects is ascii. This leads to
-    exception when converting something different than ascii. And this
-    exception is not catched inside wxPython and leads to segfault.
-
-    So if wxPython supports unicode, we give it unicode, otherwise locale
-    dependant text.
-    """
-    try:
-        if wx.USE_UNICODE:
-            if type(txt) == type(u''):
-                return txt
-            if type(txt) == type(''):
-                return unicode(txt, localecharset)
-        else:
-            if type(txt) == type(''):
-                return txt
-            if type(txt) == type(u''):
-                return str(htmlencoder(txt, 'replace')[0])
-        return str(txt)
-    except UnicodeEncodeError:
-        return '???'
-
-def UnicodeConv(txt):
-    """
-    This function coverts something (txt) to string form usable by wxPython. There
-    is problem that in default configuration in most distros (maybe all) default
-    encoding for unicode objects is ascii. This leads to exception when converting
-    something different than ascii. And this exception is not catched inside
-    wxPython and leads to segfault.
-
-    So if wxPython supports unicode, we give it unicode, otherwise locale
-    dependant text.
-    """
-    try:
-        if type(txt) == type(u''):
-            return txt
-        if type(txt) == type(''):
-            return unicode(txt, localecharset)
-        return unicode(str(txt), localecharset)
-    except UnicodeEncodeError:
-        return unicode('???')
-
-def Str_(txt):
-    return StrConv(_(txt))
-
-def HtmlStr_(txt):
-    return HtmlStrConv(_(txt))
 
 def GetItemType(txt):
     if txt == '':
         return None
-    elif txt[-8:] == 'DATETIME':
+    elif txt[-8:] == 'DATETIME' or txt == 'Date' or txt == 'LastModified' or txt == 'LAST_MODIFIED':
         return 'datetime'
-    elif txt[-4:] == 'DATE' or txt == 'Date':
+    elif txt[-4:] == 'DATE':
         return 'date'
-    elif txt == 'TEXT' or txt == 'LOCATION' or txt[:4] == 'Text':
+    elif txt in ['TEXT', 'DESCRIPTION', 'LOCATION', 'LUID'] or txt[:4] == 'Text':
         return 'text'
     elif txt == 'PHONE' or txt[:6] == 'Number':
         return 'phone'
@@ -182,6 +76,7 @@ def SearchLocation(lst, loc, second = None):
     return result
 
 def MatchesText(item, match, num):
+    testkeys = ['Value', 'Text', 'Number']
     for x in item:
         if type(item) == dict:
             val = item[x]
@@ -194,12 +89,17 @@ def MatchesText(item, match, num):
             return True
         elif type(val) == list:
             for i in range(len(val)):
-                val2 = val[i]['Value']
-                if type(val2) in (str, unicode):
-                    if match.search(val2) != None:
-                        return True
-                elif num is not None and type(val2) == int and num == val2:
-                    return True
+                for key in testkeys:
+                    try:
+                        val2 = val[i][key]
+                        if type(val2) in (str, unicode):
+                            if match.search(val2) != None:
+                                return True
+                        elif num is not None and type(val2) == int and num == val2:
+                            return True
+                    except KeyError:
+                        # Ignore not found keys
+                        pass
     return False
 
 
@@ -254,6 +154,10 @@ def GetNumberLink(lst, number):
     return GetContactLink(lst, i, number)
 
 def GetTypeString(type, value, values, linkphone = True):
+    '''
+    Returns string for entry in data dictionary. Formats it according to
+    knowledge of format types.
+    '''
     t = GetItemType(type)
     if t == 'contact':
         i = SearchLocation(values['contact']['ME'], value)
@@ -279,6 +183,7 @@ def ParseMemoryEntry(entry):
     number = ''
     number_result = ''
     name_result = ''
+    date = None
     for i in entry['Entries']:
         if i['Type'] == 'Text_Name':
             name = i['Value']
@@ -286,6 +191,8 @@ def ParseMemoryEntry(entry):
             first = i['Value']
         if i['Type'] == 'Text_LastName':
             last = i['Value']
+        if i['Type'] == 'Date':
+            date = i['Value']
         if i['Type'] == 'Text_Company':
             company = i['Value']
         if i['Type'] == 'Number_General':
@@ -310,10 +217,10 @@ def ParseMemoryEntry(entry):
     entry['Number'] = number_result
     entry['Name'] = name_result
     entry['Synced'] = False
+    entry['Date'] = date
     return entry
 
 def ParseTodo(entry):
-    _ = Str_
     dt = ''
     text = ''
     completed = ''
@@ -337,14 +244,67 @@ def ParseCalendar(entry):
     start = ''
     end = ''
     text = ''
+    description = ''
+    tone_alarm = None
+    silent_alarm = None
+    recurrence = None
     for i in entry['Entries']:
         if i['Type'] == 'END_DATETIME':
             end = str(i['Value'])
         elif i['Type'] == 'START_DATETIME':
             start = str(i['Value'])
+        elif i['Type'] == 'TONE_ALARM_DATETIME':
+            tone_alarm = _('enabled (tone)')
+        elif i['Type'] == 'SILENT_ALARM_DATETIME':
+            silent_alarm = _('enabled (silent)')
         elif i['Type'] == 'TEXT':
             text = i['Value']
-    entry['Text'] = text
+        elif i['Type'] == 'DESCRIPTION':
+            description = i['Value']
+        elif i['Type'] == 'REPEAT_MONTH':
+            recurrence = _('yearly')
+        elif i['Type'] == 'REPEAT_DAY':
+            recurrence = _('monthly')
+        elif i['Type'] == 'REPEAT_FREQUENCY':
+            if i['Value'] == 1:
+                recurrence = _('daily')
+            elif i['Value'] == 2:
+                recurrence = _('biweekly')
+        elif (i['Type'] == 'REPEAT_DAYOFWEEK'):
+            if i['Value'] == 1:
+                recurrence = _('weekly on monday')
+            elif i['Value'] == 2:
+                recurrence = _('weekly on tuesday')
+            elif i['Value'] == 3:
+                recurrence = _('weekly on wednesday')
+            elif i['Value'] == 4:
+                recurrence = _('weekly on thursday')
+            elif i['Value'] == 5:
+                recurrence = _('weekly on friday')
+            elif i['Value'] == 6:
+                recurrence = _('weekly on saturday')
+            elif i['Value'] == 7:
+                recurrence = _('weekly on sunday')
+
+    if tone_alarm is not None:
+        entry['Alarm'] = tone_alarm
+    elif silent_alarm is not None:
+        entry['Alarm'] = silent_alarm
+    else:
+        entry['Alarm'] = _('disabled')
+
+    if recurrence is None:
+        entry['Recurrence'] = _('nonrecurring')
+    else:
+        entry['Recurrence'] = recurrence
+
+    if text == '':
+        entry['Text'] = description
+    elif description == '':
+        entry['Text'] = text
+    else:
+        entry['Text'] = '%s (%s)' % (text, description)
+
     entry['Start'] = start
     entry['End'] = end
     entry['Synced'] = False
@@ -409,7 +369,6 @@ def ProcessMessages(list, synced):
     return {'read':read, 'unread':unread, 'sent':sent, 'unsent':unsent}
 
 def FormatError(txt, info):
-    _ = Str_
     if info['Code'] == gammu.Errors['ERR_NOTSUPPORTED']:
         message = _('Your phone doesn\'t support this function.')
     elif info['Code'] == gammu.Errors['ERR_NOTIMPLEMENTED']:
@@ -426,6 +385,12 @@ def FormatError(txt, info):
         message = _('Please close opened menu in phone and retry, data can not be accessed while you have opened them.')
     elif info['Code'] == gammu.Errors['ERR_TIMEOUT']:
         message = _('Timeout while trying to communicate with phone. Maybe phone is not connected (for cable) or out of range (for bluetooth or IrDA).')
+    elif info['Code'] == gammu.Errors['ERR_DEVICENOTEXIST']:
+        message = _('Device for communication with phone does not exist. Maybe you don\'t have phone plugged or your configuration is wrong.')
+    elif info['Code'] == gammu.Errors['ERR_DEVICENOPERMISSION']:
+        message = _('Can not access device for communication with phone.')
+        if sys.platform == 'linux2':
+            message += ' ' + _('Maybe you need to be member of some group to have acces to device.')
     else:
         message = '%s %s\n%s %s\n%s %d' % (_('Description:'), StrConv(info['Text']), _('Function:'), info['Where'], _('Error code:'), info['Code'])
     return StrConv(txt + '\n\n' + message)
@@ -436,3 +401,13 @@ def FixupMaskedEdit(edit):
         fgc = wx.SystemSettings.GetColour(wx.SYS_COLOUR_WINDOWTEXT)
         setattr(edit, '_validBackgroundColour', bgc)
         setattr(edit, '_foregroundColour', fgc)
+
+def GetWebsiteLang():
+    (loc, charset) = locale.getdefaultlocale()
+    try:
+        if loc[:2].lower() == 'cs':
+            return 'cz.'
+        return ''
+    except TypeError:
+        return ''
+
