@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Wammu top level module
@@ -6,7 +7,7 @@ Wammu top level module
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -22,6 +23,7 @@ this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 '''
 
-__version__ = '0.17'
+__version__ = '0.22'
 
 gammu_error = None
+configuration = None
